<?php

/**
 * Elementor Widget
 * @package eleblog
 * @since 1.0.0
 */

namespace Elementor;

class ELeblog_Video_Grid extends Widget_Base
{

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name()
	{
		return 'eleblog_video_grid';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @return string Widget title.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_title()
	{
		return esc_html__('Video Grid', 'ele-blog');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @return string Widget icon.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_icon()
	{
		return 'eicon-image-bold';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories()
	{
		return ['ele-blog'];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls()
	{

		/*
		* Display post
		*/
		$this->start_controls_section(
			'settings_display_post',
			[
				'label' => esc_html__('Video Grid', 'ele-blog'),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'ppr',
			[
				'label'   => esc_html__('Amount of item to display', 'ele-blog'),
				'type'    => Controls_Manager::TEXT,
				'default' => 4
			]
		);


		$this->add_control(
			'style',
			[
				'label'   => esc_html__('Style', 'ele-blog'),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'one' => esc_html__('Style One', 'ele-blog'),
					'two' => esc_html__('Style Two', 'ele-blog'),
				),
				'default' => 'one'

			]
		);

		$this->add_control(
			'order',
			[
				'label'   => esc_html__('Order', 'ele-blog'),
				'type'    => Controls_Manager::SELECT2,
				'options' => array(
					'desc' => esc_html__('DESC', 'ele-blog'),
					'asc'  => esc_html__('ASC', 'ele-blog'),
				),
				'default' => 'desc'

			]
		);

		$this->add_control(
			'select_cat',
			[
				'label'    => esc_html__('Select Category', 'ele-blog'),
				'type'     => Controls_Manager::SELECT2,
				'multiple' => true,
				'options'  => ele_blog_post_category(),

			]
		);


		$this->add_control(
			'exclude_cat',
			[
				'label'    => esc_html__('Exclude Category', 'ele-blog'),
				'type'     => Controls_Manager::SELECT2,
				'multiple' => true,
				'options'  => ele_blog_post_category(),
			]
		);

		$this->add_control(
			'select_tag',
			[
				'label'    => esc_html__('Select tag', 'ele-blog'),
				'type'     => Controls_Manager::SELECT2,
				'multiple' => true,
				'options'  => ele_blog_post_tag(),
			]
		);

		$this->end_controls_section();


		//style
		$this->start_controls_section(
			'video_grid_style',
			[
				'label' => esc_html__('Style', 'ele-blog'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		// Title color
		$this->add_control(
			'title_color',
			[
				'label'     => esc_html__('Title Color', 'ele-blog'),
				'type'      => Controls_Manager::COLOR,
				'default'   => '#fff',
				'selectors' => [
					'{{WRAPPER}} .single-post-list-wrap.style-white .media .media-body h6 a' => 'color: {{VALUE}};',
				],
			]
		);

		// Title color
		$this->add_control(
			'title_hover_color',
			[
				'label'     => esc_html__('Title Hover Color', 'ele-blog'),
				'type'      => Controls_Manager::COLOR,
				'default'   => '#2979ff',
				'selectors' => [
					'{{WRAPPER}} .single-post-list-wrap.style-white .media .media-body h6 a:hover' => 'color: {{VALUE}};',
				],
			]
		);


		//title typography
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'           => 'title_typography',
				'label'          => esc_html__('Title Typography', 'ele-blog'),
				'selector'       => '{{WRAPPER}} .single-post-list-wrap.style-white .media .media-body h6 a',
				'fields_options' => [
					// first mimic the click on Typography edit icon
					'typography'  => ['default' => 'yes'],
					// then redifine the Elementor defaults
					'font_size'   => ['default' => ['size' => 18]],
					'font_weight' => ['default' => 500],
					'line_height' => ['default' => ['size' => 24]],
				],
			]
		);

		$this->end_controls_section();

		//Backgroud
		$this->start_controls_section(
			'section_background',
			[
				'label'     => esc_html__('Backgroud', 'ele-blog'),
				'tab'       => Controls_Manager::TAB_STYLE,
				'condition' => [
					'style' => 'one',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name'     => 'background',
				'label'    => __('Background', 'ele-blog'),
				'types'    => ['classic'],
				'selector' => '{{WRAPPER}} .bg-black',
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render Elementor widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render()
	{

		$settings = $this->get_settings_for_display();

		//for first column
		$args = array(
			'post_type'           => 'post',
			'post_status'         => 'publish',
			'ignore_sticky_posts' => 1,
			'posts_per_page'      => $settings['ppr'],
		);

		$args['order'] = $settings['order'];


		if (!empty($settings['exclude_cat'])) {
			$args['category__not_in'][] = array_values($settings['exclude_cat']);
		}

		if (!empty($settings['select_cat'])) {
			$catgory             = implode(', ', $settings['select_cat']);
			$args['tax_query'][] = array(
				'taxonomy' => 'category',
				'field'    => 'id',
				'terms'    => array_values($settings['select_cat'])
			);
		}

		if (!empty($settings['select_tag'])) {
			$args['tax_query'][] = array(
				'taxonomy' => 'post_tag',
				'field'    => 'id',
				'terms'    => array_values($settings['select_tag'])
			);
		}


		if ('two' == $settings['style']) :
?>
			<div class="video-area pd-top-80">
				<div class="eblog-container">
					<div class="eblog-row">
						<?php
						$query = new \WP_Query($args);
						if ($query->have_posts()) :
							while ($query->have_posts()) : $query->the_post();
								global $post;
								$cat   = get_the_category();
								$video     = get_post_meta($post->ID, 'ele_blog_post_video', true);
								$img_id    = get_post_thumbnail_id(get_the_ID());
								$img_id    = get_post_thumbnail_id(get_the_ID());
								$image_alt = get_post_meta($img_id, '_wp_attachment_image_alt', true);
								$src       = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'full', false, '');
						?>
								<div class="eblog-col-lg-6">
									<div class="single-post-wrap style-overlay">
										<div class="thumb">
											<img src="<?php echo esc_url(ele_blog_img_resize($src[0], 540, 275, true)); ?>" alt="<?php echo esc_attr($image_alt); ?>">
											<?php if (isset($video['videoid'])) : ?>
												<a href="https://www.youtube.com/watch?v=<?php echo esc_attr($video['videoid']); ?>" class="video-play-btn play-btn-large play-btn-yellow mfp-iframe" tabindex="0"><i class="fa fa-play"></i></a>
											<?php endif; ?>
										</div>
										<div class="details">
											<div class="post-meta-single">
												<?php
												if (isset($cat[0])) :
												?>
													<a class="tag-base ele-<?php echo esc_attr($cat[0]->slug); ?>" href="<?php echo get_category_link($cat[0]->term_id); ?>">
														<?php echo get_cat_name($cat[0]->term_id); ?>
													</a>
												<?php endif; ?>
												<p><?php eleblog_post_date(); ?></p>
											</div>
											<h6 class="title">
												<a href="<?php the_permalink(); ?>">
													<?php the_title(); ?>
												</a>
											</h6>
										</div>
									</div>
								</div>
						<?php endwhile;
							wp_reset_postdata();
						endif; ?>
					</div>
				</div>
			</div>
		<?php else : ?>
			<div class="newsletter-area bg-black pd-top-80  pd-bottom-50">
				<div class="eblog-container">
					<div class="eblog-row">
						<div class="eblog-col-xl-12">

							<div class="eblog-row">
								<?php
								$query = new \WP_Query($args);
								if ($query->have_posts()) :
									while ($query->have_posts()) : $query->the_post();
										global $post;
										$cat       = get_the_category();
										$video     = get_post_meta($post->ID, 'ele_blog_post_video', true);
										$img_id    = get_post_thumbnail_id(get_the_ID());
										$image_alt = get_post_meta($img_id, '_wp_attachment_image_alt', true);
										$src       = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'full', false, '');
								?>
										<div class="eblog-col-xl-6 eblog-col-lg-6">
											<div class="single-post-list-wrap style-two style-white text-left">
												<div class="media">
													<div class="media-left">
														<img src="<?php echo esc_url(ele_blog_img_resize($src[0], 270, 200, true)); ?>" alt="<?php echo esc_attr($image_alt); ?>">
														<?php
														if (isset($video['videoid'])) :
														?>
															<a href="https://www.youtube.com/watch?v=<?php echo esc_attr($video['videoid']); ?>" class="video-play-btn play-btn-small play-btn-gray mfp-iframe" tabindex="0"><i class="fa fa-play"></i></a>
														<?php endif; ?>
													</div>
													<div class="media-body align-self-center">
														<div class="details">
															<div class="post-meta-single">
																<ul>
																	<?php
																	if (isset($cat[0])) :
																	?>
																		<li>
																			<a href="<?php echo get_category_link($cat[0]->term_id); ?>" class="tag-base ele-<?php echo esc_attr($cat[0]->slug); ?>">
																				<?php echo get_cat_name($cat[0]->term_id); ?>
																			</a>
																		</li>
																	<?php endif; ?>
																	<li><?php eleblog_post_date(); ?></li>
																</ul>
															</div>
															<h6 class="title mt-2">
																<a href="<?php the_permalink(); ?>">
																	<?php the_title(); ?>
																</a>
															</h6>
															<p><?php echo wp_trim_words(get_the_content(), 14, ' '); ?></p>
														</div>
													</div>
												</div>
											</div>
										</div>
								<?php endwhile;
									wp_reset_postdata();
								endif; ?>
							</div>
						</div>
					</div>
				</div>
			</div>
		<?php endif; ?>

<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type(new ELeblog_Video_Grid());
